#include "StdAfx.h"
#include "NumberImagePanel.h"
#include "XMLUtil.h"
#include "ScriptletConstant.h"
#include <math.h>

namespace tipuio
{
	static const TCHAR SCRIPTLET_NUMBERIMAGEPANEL_NODE[] = _T("numberimagepanel");
	static const TCHAR SCRIPTLET_NUMBER_NODE[] = _T("number");

	REGISTER_COMPONENT_CREATOR(_T("NumberImagePanel"), NumberImagePanel);
	NumberImagePanel::NumberImagePanel(void)
	{
		m_Number = 0;
		for (int i=0; i<10; i++)
		{
			m_Image[i] = NULL;
		}
	}

	NumberImagePanel::~NumberImagePanel(void)
	{
	}
	void NumberImagePanel::CreateNumberImage()
	{
		if (m_Image[0] != NULL) return;

		TCHAR imageID[16] = {0};
		for (int i=0; i<10; i++)
		{
			_stprintf_s(imageID, 16, _T("%d"), i);
			m_Image[i] = this->FindName(imageID);		
		}
	}
	void NumberImagePanel::OnCreate()
	{
		__super::OnCreate();

		CreateNumberImage();
	}
	BOOL NumberImagePanel::ModifyComponent(CContainer* pParent, TiXmlElement* pNode)
	{
		__super::ModifyComponent(pParent, pNode);

		TCHAR szValue[SCRIPTLET_MAX_VALUE] = {0};
		long lValue = 0;

		USES_CONVERSION;
		//inherit
		if (XMLUtil::GetAttrValue(pNode, CT2CA(SCRIPTLET_NUMBER_NODE), lValue) ||
			XMLUtil::GetValueAsAttr(pNode, CT2CA(SCRIPTLET_NUMBER_NODE), lValue))
		{
			SetNumber(lValue);
		}
		return TRUE;
	}
	BOOL NumberImagePanel::SetProperty(LPCTSTR property, CComVariant value)
	{
		//number
		if (_tcsicmp(SCRIPTLET_NUMBER_NODE, property) == 0)
		{
			int number = value.intVal;
			this->SetNumber(number);
			this->Invalidate();
			return TRUE;
		}
		return FALSE;
	}
	BOOL NumberImagePanel::GetProperty(LPCTSTR property, CComVariant& value)
	{
		//number
		if (_tcsicmp(SCRIPTLET_NUMBER_NODE, property) == 0)
		{
			value = GetNumber();
			return TRUE;
		}
		return FALSE;
	}
	void NumberImagePanel::SetNumber(int number)
	{
		if (number < 0) return;

		m_Number = number;

		CreateNumberImage();

		CComponent* content = this->FindName(_T("content"));
		if (content != NULL)
		{
			content->RemoveAll();
			
			int num = GetNumber();
			TCHAR numString[64] = {0};
			_stprintf_s(numString, 64, _T("%d"), num);
			int count = _tcslen(numString);

			for (int i=count-1; i>=0; i--)
			{
				int n = num / int(pow(10., i));
				if (0 <= n && n <= 9 && m_Image[n] != NULL)
				{
					m_Image[n]->AddRef();
					content->Add(m_Image[n]);
				}
				num = num % int(pow(10., i));
			}
			this->RecalcLayout(TRUE);
		}
	}
};

